@@ -7,11 +7,12 @@
 #     __version__ = None
 #     pass
 
-from importlib.metadata import version
+# from importlib.metadata import version
 
-from . import io
+from . import dataframe, io
 from .csv_object import Csv
-from .dictionary import DictDefault
+from .dataset_ts_long import AtpDatasetTsLong
+from .dict_default import DictDefault
+from .histogram import HistogramContinue
 from .records import Records
-
-__version__ = version("atpdataset")
+# __version__ = version("atpdataset")
